/*!
  \file libskype/Loggers.cpp

  \brief Cross-platform loggers implementation
  
  $Id: Loggers.cpp,v 1.8 2006/05/21 13:46:19 vit Exp $

  \author (c) Ice Brains Software, llc.  http://www.icebrains-soft.com
  \date   01.08.2005 08:51:42 MSD
*/

#include "h/Loggers.h"

#include <sstream>
#include <boost/date_time/posix_time/posix_time.hpp>

std::string& NoLogPrefix::operator()(const LogLevel_t& _lvl)
{
   return empty; 
};

LvlLogPrefix::LvlLogPrefix()
{
   levels_str[LlDbg]    	=  "[Debug] ";
   levels_str[LlInfo]   	=  "[Info] ";
   levels_str[LlError]  	=  "[Warning] ";
   levels_str[LlCritical] 	= "[Critical] ";
};

std::string& LvlLogPrefix::operator()(const LogLevel_t& _lvl)
{ 
   buf = levels_str[_lvl]; 
   
   return buf;
};

std::string& LvlTimeLogPrefix::operator()(const LogLevel_t& _lvl) 
{
   std::string& out = LvlLogPrefix::operator()(_lvl);
   std::stringstream ss;
   ss << boost::posix_time::second_clock::local_time() << ' ';
   out.insert(0, ss.str());
   
   return out;
};

LoggersChain::LoggersChain() throw() 
	     : 	LogAbility(LogFunc_t(this, &LoggersChain::Do))
{};

LoggersChain::LoggersChain(const LoggersChain&)
	    : LogAbility(LogFunc_t(this, &LoggersChain::Do))
{};


void LoggersChain::AddLogFunc(const LogFunc_t& _logger)
{
   logger.push_back(_logger);
};

void LoggersChain::PopBackLogger(void)
{
   logger.pop_back();
};

void LoggersChain::Do(const LogLevel_t _lvl, const char* _fmt, va_list _args)
{
   std::list<LogFunc_t>::iterator p = logger.begin();

   while(p != logger.end()) {
	(*p)(_lvl, _fmt, _args);
        p++;
   };
};
