/*!
  \file audio.cpp

  \brief AudioSettings class defination
  
  $Id: audio.cpp,v 1.4 2006/04/17 06:44:11 vit Exp $

  \author (c) Ice Brains Software, llc.  http://www.icebrains-soft.com
  \date   30.03.2006 23:28:19 MSD
*/

#include "h/Audio.h"

using namespace Ice;

AudioAttrsDesc_t::AttrsDescription()
{
  Add(auAudioIn, "AUDIO_IN");
  Add(auAudioOut, "AUDIO_OUT");
  Add(auRinger, "RINGER");
  Add(auPCSpeaker, "PCSPEAKER");
  Add(auAGC, "AGC"); 
  Add(auAEC, "AEC");
  Add(auMute, "MUTE");
};	

AudioSettings::AudioSettings(SkypeConnection& _sc, const LogFunc_t& _log_func)
	   : Parent_t(_sc, *this, "", 0, _log_func), sc(_sc)
{ Init(); };

AudioSettings::AudioSettings(SkypeConnection& _sc, const ObjErrHandler_t& _eh, const LogFunc_t& _log_func)
	   : Parent_t(_sc, *this, "", 0, _eh, _log_func), sc(_sc)
{ Init(); };

void AudioSettings::Init()
{	
  const char* re_str = 	"^(AUDIO_IN|AUDIO_OUT|RINGER|AGC|AEC|MUTE|PCSPEAKER)\\s+(.*)$";
  
  struct Parser_t::SkypeObjRegEx re;
  re.resp = boost::regex(re_str);
  re.resp_value_pos = 2;
  re.event_attr_pos = 1;
  re.event_value_pos = 2;
  parser.SetRegEx(re);
  
  id = sc.RegisterCallback(re_str, RegExNotify_t(this, &AudioSettings::ProcessEvent));	
};

AudioSettings::~AudioSettings()
{
  sc.UnRegisterCallback("^(AUDIO_IN|AUDIO_OUT|RINGER|AGC|AEC|MUTE|PCSPEAKER)\\s+(.*)$", id);
};

