#include "h/SkypeConnection.h"
#include "SkypeTest.h"

typedef StreamLogger<LvlTimeLogPrefix> MyLogger_t;
MyLogger_t logger(std::cout);
LogFunc_t lf(&logger, &MyLogger_t::Do);


void DefaultCallback(const std::string& s)
{
	fprintf(stdout, "%s: '%s'\n", __FUNCTION__, s.c_str());	
};

//--- Tutorial example code ---
void SimpleHandler(const std::string& msg)
{ 
	std::cout << "SimpleHandler: '" << msg << "'" << std::endl; 
};

void RegExHandler(const boost::cmatch& m)
{
	std :: cout << "RegExHandler: '" << m[0] << "'" << std::endl;
	for(int i=0;i<m.size();i++) 
	{
		std::cout << " match[" << i << "] = '" << m[i] << "'";
		std::cout << std::endl;
	}
};
//--- End of tutorial example code ---

int main(int argc, char* argv[])
{
    SkypeConnection sk(argv[0], SimpleHandler_t(DefaultCallback), lf);

//--- Tutorial example code ---
	sk.RegisterCallback("^\\s*CONNSTATUS\\s+(ONLINE|CONNECTING)\\s*$", SimpleHandler_t(SimpleHandler));
	sk.RegisterCallback("^\\s*CURRENTUSERHANDLE\\s+([^\\s]+)\\s*$", RegExNotify_t(RegExHandler));
//--- End of tutorial example code ---

    sk.Attach();
    sk << DisableIds << "PROTOCOL 99" << flush << EnableIds;
	const boost::posix_time::seconds tm(1);
	ProcessSkypeMsgs(sk, tm);

	return 0;
}

