#include "h/SkypeConnection.h"
#include "SkypeTest.h"

typedef StreamLogger<LvlTimeLogPrefix> MyLogger_t;
MyLogger_t logger(std::cout);
LogFunc_t lf(&logger, &MyLogger_t::Do);

void DefaultCallback(const std::string& s)
{
	fprintf(stdout, "%s: '%s'\n", __FUNCTION__, s.c_str());	
};

//--- Tutorial example code ---
void RespHandler(const std::string& msg)
{ 
	std::cout << "RespHandler: '" << msg << "'" << std::endl; 
};

void ErrHandler(const int& err_code, const std::string& err_msg, const std::string& full_err_msg)
{ 
	std::cout << "Error code: " << err_code << std::endl;
	std::cout << "Error message: " << err_msg << std::endl;
	std::cout << "Full error message: " << full_err_msg << std::endl;
};
//--- End of tutorial example code ---

int main(int argc, char* argv[])
{
    SkypeConnection sk(argv[0], SimpleHandler_t(DefaultCallback), lf);

    sk.Attach();
    sk << DisableIds << "PROTOCOL 99" << flush << EnableIds;
	const boost::posix_time::seconds tm(1);

//--- Tutorial example code ---
	sk << "PING" << Flush(RespHandler, ErrHandler);
	sk << "INCORRECT COMMAND" << Flush(RespHandler, ErrHandler);
//--- End of tutorial example code ---

	ProcessSkypeMsgs(sk, tm);

	return 0;
}

