/*!
  \file Audio.h

  \brief Audio settings
  
  $Id: Audio.h,v 1.3 2006/04/03 12:18:03 vit Exp $

  \author (c) Ice Brains Software, llc.  http://www.icebrains-soft.com
  \date   30.03.2006 23:21:13 MSD
*/

#ifndef AUDIO_SPP_H
#define AUDIO_SPP_H

#include "SkypeObj.h"

namespace Ice {

/// Possible audio properties
typedef enum {   
	/// Audio input device	
	auAudioIn,
	/// Audio output device
	auAudioOut,
	/// Ringer device
	auRinger,
	/// Turn PC Speaker ON or OFF 
	auPCSpeaker,
	/// Automatic Gain Control
	auAGC, 
	/// Automatic Echo Cancellation
	auAEC,
	/// Mute status
	auMute
} AudioAttrs_t;

/// Audio properties description
typedef AttrsDescription<AudioAttrs_t> AudioAttrsDesc_t;

/// Describes attributes of Skype object "AudioSettings" 
template <>
class AttrsDescription<AudioAttrs_t> : public AttrsDescriptionBase<AudioAttrs_t> {
public:
	/// Fills description
	AttrsDescription();
};

/*!
  \brief Audio settings - AUDIO_IN, AUDIO_OUT, RINGER, MUTE, AEC, AGC, PCSpeaker settings

  These settings can be obtained and set with the help of the object of this class.  
  Currently this object can be successfully used only in Skype for Windows version 
  because unfortunatelly Skype for linux API doesn't support GET/SET commands for these settings.
*/  
class AudioSettings : public SkypeObject<AudioSettings, AudioAttrs_t, SkypeNoIdObjCmdFormatter> {
public:
	/*!
  	  \brief  Constructs AudioSettings object with DEFAULT error handler.  
  		  
	  	  Default error handler doesn't handle any error at all.
		  
  	  \param _sc 		Reference to the Skype Connection
	  \param _log_func	Reference to the logger. This logger will be used to log any messages inside the object.
	*/
	AudioSettings(SkypeConnection& _sc, const LogFunc_t& _log_func = DummyLogger);
	/*!
	  \brief  Constructs AudioSettings object with NON-DEFAULT (user-supplied) error handler.  

	  \param _sc		Reference to Skype Connection
	  \param _eh		Error hanlder.  This functor will be called in case of errors.
	  \param _log_func	Reference to the logger. This logger will be used to log any messages inside the object.
	*/
	AudioSettings(SkypeConnection& _sc, const ObjErrHandler_t& _eh, const LogFunc_t& _log_func = DummyLogger);
	/// Unregistrates event handlers associated with the object
	~AudioSettings();
private:
	/// Object-specific initialization.  Called from constructors 
	void Init();
	/// Identifier of the registered event handler
	unsigned id;
	/// Reference to the Skype Connection
	SkypeConnection& sc;
};

}; // namespace Ice
#endif // AUDIO_SPP_H
