/*!
  \file SkypeTest.h

  \brief  Common testing functions

  $Id: SkypeTest.h,v 1.8 2006/05/31 12:09:32 tarle Exp $

  \author (c) Ice Brains Software, llc.  http://www.icebrains-soft.com
  \date   12.08.2005 17:29:35 MSD
*/

#include "h/Cfg.h"
#include "h/AttrsDesc.h"
#include "h/SkypeConnection.h"
#include "h/utils.h"

#include <cstdio>

#include <vector>
#include <algorithm>

#ifdef SKYPE_MSC
// Fix problem (long warnings) with Boost.Test
#pragma warning ( disable : 4805) 
#endif //SKYPE_MSC

#include <boost/test/unit_test.hpp>
#include <boost/test/unit_test_suite.hpp>

/*!
  \brief  Reads and handles Skype messages during time tm	

  There are different implementation of this function for different operation system
  
  \param sc  Reference to Skype connection
  \param tm  Time to process messages
*/
void ProcessSkypeMsgs(SkypeConnection& sc, const boost::posix_time::time_duration& tm);

/*!
  \brief  Asks all readable attributes of Skype object
  
  \param _obj		Reference to Skype object
  \param _attrs_vec	Reference to the vector of attributes.  It will be filled by asked attributed upon return
*/
template <typename Attrs, class Obj> void AskAttrs(Obj& _obj, std::vector<Attrs>& _attrs_vec);

/*!
  \brief Compares two vectors: tested and etalon

  \param _tst		Tested vector
  \param _etalon	Etalon vector
*/
template <class T> void CmpVecs(std::vector<T>& _tst, std::vector<T>& _etalon);

/**********************************************************************************************************/
/************************************ Implementation ******************************************************/
/**********************************************************************************************************/

void ProcessSkypeMsgs(SkypeConnection& sc, const boost::posix_time::time_duration& tm)
{
  fprintf(stdout, "Entering waiting stage for %d seconds\n", tm.total_seconds());	
  boost::posix_time::ptime start(boost::posix_time::microsec_clock::universal_time());
  const boost::posix_time::millisec wd(500);
  const boost::posix_time::millisec ws(10);
 
  #if defined(SKYPE_MINGW) || defined(SKYPE_MSC)
  MSG oMessage;
  #endif // SKYPE_MINGW || SKYPE_MSC

  do {
	#if defined(SKYPE_MINGW) || defined(SKYPE_MSC)
	if(PeekMessage(&oMessage, 0, 0, 0, PM_REMOVE) == 0) 
	{
		Impl::Sleep(ws);
		continue;
	}
	TranslateMessage(&oMessage);
	DispatchMessage(&oMessage);
	Impl::Sleep(ws);
 	#else 
	while(sc()) { Impl::Sleep(wd); };
	#endif // SKYPE_MINGW || SKYPE_MSC
  } while( (boost::posix_time::microsec_clock::universal_time()- start) < tm);	  
};	

template <typename Attrs, class Obj> void AskAttrs(Obj& _obj, std::vector<Attrs>& _attrs_vec)
{
  Ice::AttrsDescription<Attrs> desc;
  typedef typename Ice::AttrsDescription<Attrs>::const_iterator CI;
  for(CI p = desc.begin();p != desc.end();++p) {
	if(!p->second.can_get) continue;
	_obj.AskAttr(p->first);
	_attrs_vec.push_back(p->first);
  };	  
};

template <class T> void CmpVecs(std::vector<T>& _tst, std::vector<T>& _etalon)
{
  std::sort(_tst.begin(), _tst.end());
  std::sort(_etalon.begin(), _etalon.end());
  BOOST_CHECK_EQUAL_COLLECTIONS(_etalon.begin(), _etalon.end(), _tst.begin(), _tst.end());
};


