/*!
  \file utils.cpp

  \brief Utils test
  
  $Id: utils.cpp,v 1.4 2005/09/26 10:21:05 vit Exp $

  \author (c) Ice Brains Software, llc.  http://www.icebrains-soft.com
  \date   20.07.2005 10:02:21 MSD
*/

#include "SkypeTest.h"

#include "h/utils.h"

#include <boost/test/floating_point_comparison.hpp>

using namespace boost::unit_test;

void AssertTest()
{
  BOOST_CHECK_NO_THROW(Assert(1==1));
  if(DbgMode==debug) {
	BOOST_CHECK_THROW(Assert(1==0), AssertionViolation);
  } else {
	BOOST_CHECK_NO_THROW(Assert(1==0));  
  };	  
};

void ConvertTest()
{
  // Boolean	
  BOOST_CHECK_EQUAL(GetFromString<bool>("true"), 1);
  BOOST_CHECK_EQUAL(GetFromString<bool>("1"), 1);
  BOOST_CHECK_EQUAL(GetFromString<bool>("false"), 0);
  BOOST_CHECK_EQUAL(GetFromString<bool>("0"), 0);
  BOOST_CHECK_THROW(GetFromString<bool>("False"), std::range_error);
  
  // Integer
  BOOST_CHECK_EQUAL(GetFromString<int>("-12"), -12);
  BOOST_CHECK_EQUAL(GetFromString<short int>("-523"), -523);
  BOOST_CHECK_THROW(GetFromString<short int>("99999999999999999999999999999999999999999999999999999999999"), std::range_error);
  
  // Unsigned integer
  BOOST_CHECK_EQUAL(GetFromString<unsigned>("123"), 123);
  BOOST_CHECK_THROW(GetFromString<unsigned>("0.123"), std::range_error);

  // Floating point values
  BOOST_CHECK_CLOSE(GetFromString<double>("-1e-3"), -1e-3, 0.001);
};

void NumeratorTest()
{
  Numerator<int> num;
  int id = num.IncrNum();
  BOOST_CHECK_EQUAL(num.LastNum(), id);
  
  int idd = num.IncrNum();
  BOOST_CHECK_EQUAL(++id, idd);
};

int reg_obj_cntr = 0;
unsigned ids[2];
int vs[2] = { 5, 777 };

void DoRegObj(const unsigned& _id, int& _obj)
{
  BOOST_CHECK_EQUAL(_id, ids[reg_obj_cntr]);
  BOOST_CHECK_EQUAL(_obj, vs[reg_obj_cntr++]);
};

void RegistratorTest()
{
  typedef Registrator<int> Reg_t;	
  Reg_t reg;

  ids[0] = reg.Register(vs[0]);
  ids[1] = reg.Register(vs[1]);
  
  BOOST_CHECK_EQUAL(reg.GetObjects().size(), 2);
  reg.for_each(DoRegObj);
  
  BOOST_CHECK(reg.UnRegister(ids[1]));
  BOOST_CHECK(!reg.UnRegister(ids[1]));
  BOOST_CHECK(!reg.UnRegister(ids[1]));

  BOOST_CHECK_EQUAL(reg.GetObjects().size(), 1);
};

void SleepTest()
{
  const boost::posix_time::seconds tm(2);
  
  boost::posix_time::ptime before(boost::posix_time::microsec_clock::universal_time());
  Impl::Sleep(tm);
  boost::posix_time::ptime after(boost::posix_time::microsec_clock::universal_time());
  
  boost::posix_time::time_duration d = after - before;
  BOOST_CHECK(d.total_seconds() >= 2);
  BOOST_CHECK(d.total_seconds() <= 3);
};

test_suite* init_unit_test_suite( int argc, char* argv[] )
{
    test_suite* test= BOOST_TEST_SUITE("Utilities test");
    test->add(BOOST_TEST_CASE(&AssertTest));
    test->add(BOOST_TEST_CASE(&ConvertTest));
    test->add(BOOST_TEST_CASE(&NumeratorTest));
    test->add(BOOST_TEST_CASE(&RegistratorTest));
    test->add(BOOST_TEST_CASE(&SleepTest));    
    return test;
    
}

